@@ -4,7 +4,6 @@
 import io
 import contextlib
 import functools
-import itertools
 import logging
 
 import boto3
@@ -42,6 +41,8 @@ MODES = (READ_BINARY, WRITE_BINARY)
 BINARY_NEWLINE = b'\n'
 DEFAULT_BUFFER_SIZE = 128 * 1024
 
+SUPPORTED_SCHEMES = ("s3", "s3n", 's3u', "s3a")
+
 
 def _range_string(start, stop=None):
     #
@@ -377,6 +378,9 @@ multipart upload may fail")
         #
         self.raw = None
 
+    def flush(self):
+        pass
+
     #
     # Override some methods from io.IOBase.
     #
@@ -385,7 +389,7 @@ multipart upload may fail")
         if self._buf.tell():
             self._upload_next_part()
 
-        if self._total_bytes:
+        if self._total_bytes and self._mp:
             self._mp.complete(MultipartUpload={'Parts': self._parts})
             logger.debug("completed multipart upload")
         elif self._mp:
@@ -430,8 +434,6 @@ multipart upload may fail")
         if not isinstance(b, six.binary_type):
             raise TypeError("input must be a binary string, got: %r", b)
 
-        # logger.debug("writing %r bytes to %r", len(b), self._buf)
-
         self._buf.write(b)
         self._total_bytes += len(b)
 
